@@ -30,25 +30,22 @@
 #' @importFrom rlang :=
 #' @export
 untangle2 <- function(df, regex, orig, new) {
-  orig <- dplyr::enquo(orig)
-  new <- dplyr::enquo(new)
   countmatches <- function(df, regex, orig) {
-    xtxt <- dplyr::pull(df, !!orig)
+    xtxt <- dplyr::pull(df, {{ orig }})
     sum(lengths(regmatches(xtxt, gregexpr(pattern = regex, text = xtxt))))
   }
-  nmatches <- countmatches(df, regex, orig)
+  nmatches <- countmatches(df, regex, {{ orig }})
   if (nmatches == 0) {
     message("no matches")
   } else if (nmatches == 1) {
     message(paste(nmatches, "match"))
-  }
-  else {
+  } else {
     message(paste(nmatches, "matches"))
   }
   to_fill <- dplyr::mutate(
     df,
-    !!new := dplyr::if_else(grepl(regex, !!orig), !!orig, NA_character_)
+    {{ new }} := dplyr::if_else(grepl(regex, {{ orig }}), {{ orig }}, NA_character_)
   )
-  dffilled <- tidyr::fill(to_fill, !!new)
-  dplyr::filter(dffilled, !grepl(regex, !!orig))
+  dffilled <- tidyr::fill(to_fill, {{ new }})
+  dplyr::filter(dffilled, !grepl(regex, {{ orig }}))
 }
